<p align="center">
<img src="https://github.com/MarcG-LBMC-Lyos/QCTMA/blob/main/imgs/Illustration.jpg?raw=true">
</p>
Injects material (Young's modulus) to each element, based on a Dicom stack, and gray level to Young's modulus relationships. Specifically designed to be used with Ansys .cdb meshes.